@@ -1,39 +1,32 @@
 # -*- coding: utf-8 -*-
 
-from db_file_storage.storage import DatabaseFileStorage
+# django imports
 from django.core.servers.basehttp import FileWrapper
 from django.http import HttpResponse, HttpResponseBadRequest
+from django.utils.translation import ugettext as _
+
+# project imports
+from db_file_storage.storage import DatabaseFileStorage
 
 
 storage = DatabaseFileStorage()
 
 
-def download_file(request):
+def get_file(request, add_attachment_headers):
     name = request.GET.get('name')
-    
+
     try:
         dict_file = storage.open(name)
     except:
-        return HttpResponseBadRequest(u'Requisição inválida.')
-    
+        return HttpResponseBadRequest(_('Invalid request'))
+
     response = HttpResponse(
         FileWrapper(dict_file['file']),
-        content_type = dict_file['mimetype']
+        content_type=dict_file['mimetype']
     )
-    response['Content-Disposition'] = 'attachment; filename=%s' % dict_file['filename']
+
+    if add_attachment_headers:
+        response['Content-Disposition'] = \
+            'attachment; filename=%s' % dict_file['filename']
+
     return response
-    
-def get_file(request):
-    name = request.GET.get('name')
-    
-    try:
-        dict_file = storage.open(name)
-    except:
-        return HttpResponseBadRequest(u'Requisição inválida.')
-    
-    response = HttpResponse(
-        FileWrapper(dict_file['file']),
-        content_type = dict_file['mimetype']
-    )
-    return response
-    
